summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
authoroehhar <harald.oehlmann@elmicron.de>2018-09-22 20:31:07 (GMT)
committeroehhar <harald.oehlmann@elmicron.de>2018-09-22 20:31:07 (GMT)
commitdbae6fd8e676c40daac803ac99de1368c9d229a8 (patch)
tree593f65ddc2e8ec647886fdbb23ddf8fc71c51eb8 /generic
parent33fbb40b45f7662f1c959f330873d33faaf77105 (diff)
downloadtk-dbae6fd8e676c40daac803ac99de1368c9d229a8.zip
tk-dbae6fd8e676c40daac803ac99de1368c9d229a8.tar.gz
tk-dbae6fd8e676c40daac803ac99de1368c9d229a8.tar.bz2
Use the event name of the TIP: NoManagedChild
Diffstat (limited to 'generic')
-rw-r--r--generic/tkGrid.c4
-rw-r--r--generic/tkPack.c4
2 files changed, 4 insertions, 4 deletions
diff --git a/generic/tkGrid.c b/generic/tkGrid.c
index 3f685af..6c0f5b1 100644
--- a/generic/tkGrid.c
+++ b/generic/tkGrid.c
@@ -1735,12 +1735,12 @@ ArrangeGrid(
* If the master has no slaves anymore, then don't change the master size.
* Otherwise there is no way to "relinquish" control over the master
* so another geometry manager can take over.
* Send event to "NoManagedChilds" to inform about no managed grid but
* not resized.
*/
if (masterPtr->slavePtr == NULL) {
- TkSendVirtualEvent(masterPtr->tkwin, "NoManagedChilds", NULL);
+ TkSendVirtualEvent(masterPtr->tkwin, "NoManagedChild", NULL);
return;
}
@@ -1735,12 +1735,12 @@ ArrangeGrid(
* Otherwise there is no way to "relinquish" control over the master
* so another geometry manager can take over.
- * Send event to "NoManagedChilds" to inform about no managed grid but
+ * Send event to "NoManagedChild" to inform about no managed grid but
* not resized.
*/
diff --git a/generic/tkPack.c b/generic/tkPack.c
index 3bc9103..7f165d1 100644
--- a/generic/tkPack.c
+++ b/generic/tkPack.c
@@ -602,12 +602,12 @@ ArrangePacking(
* If the master has no slaves anymore, then leave the master's size as-is.
* Otherwise there is no way to "relinquish" control over the master
* so another geometry manager can take over.
* Send event to "NoManagedChilds" to inform about no managed grid but
* not resized.
*/
if (masterPtr->slavePtr == NULL) {
- TkSendVirtualEvent(masterPtr->tkwin, "NoManagedChilds", NULL);
+ TkSendVirtualEvent(masterPtr->tkwin, "NoManagedChild", NULL);
return;
}
@@ -602,12 +602,12 @@ ArrangePacking(
* Otherwise there is no way to "relinquish" control over the master
* so another geometry manager can take over.
- * Send event to "NoManagedChilds" to inform about no managed grid but
+ * Send event to "NoManagedChild" to inform about no managed grid but
* not resized.
*/